Learn R Programming

bidsr (version 0.1.1)

download_bids_examples: Download 'BIDS' example data-sets

Description

See https://github.com/bids-standard/bids-examples for the full repository.

Usage

download_bids_examples(test = FALSE)

Value

A local path to the example repository exists or when test=FALSE; or simply FALSE if the repository is missing and test=TRUE.

Arguments

test

logical; default is FALSE, which downloads the example repository if the files are missing; an alternative choice is TRUE, which will return FALSE if the files are missing

Author

Zhengjia Wang

Examples

Run this code

download_bids_examples(test = TRUE)

Run the code above in your browser using DataLab